//	AppSettingsExample.cpp - Example of how to implement the unimplemented
//							 AppSettings bits.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "AppSettings.h"
#include "Application.h"
#include "DebugHeaders.h"

#include "TitleScreen.h"
#include "OptionsScreen.h"
#include "GamePlayState.h"

#include "drawing/GLImmediateDrawer.h"
#include "drawing/GLESDrawer.h"
#include "SnakeballSounder.h"
#include "ScreamingSnakeballGlobalData.h"

#include <sstream>

using std::wstringstream;
using std::wstring;

//------------------------------------------------------------------------------
wstring AppSettings::applicationName = L"Screaming Snakeball";
wstring AppSettings::applicationVersion = L"0.10";

//------------------------------------------------------------------------------
void AppSettings::initialise(CmdLineParams& cmdLine,
							 Application *app,
							 KeyManager& keyManager,
							 wstring& helpText)
{
	//Register your interest in any command line arguments.

	//Setup the dimensions of the drawing area.
	setDrawingDimensions(1280, 720, AlterRatio);

	//Register all possible GameStates.
	app->registerGameState(L"TitleScreen", &TitleScreen::creator, true);
	app->registerGameState(L"OptionsScreen", &OptionsScreen::creator);
	app->registerGameState(L"GamePlayState", &GamePlayState::creator);

	//Setup some default key mappings.
	// - Player 1 movement (keys).
	keyManager.addMapping(L"P1Up", L"w", true);
	keyManager.addMapping(L"P1Left", L"a", true);
	keyManager.addMapping(L"P1Right", L"d", true);
	keyManager.addMapping(L"P1Down", L"s", true);
	keyManager.addMapping(L"P1Kick", L"c", true);
	// - Player 1 movement (joystick).
	keyManager.addMapping(L"P1Up", L"Joy0Up", true);
	keyManager.addMapping(L"P1Left", L"Joy0Left", true);
	keyManager.addMapping(L"P1Right", L"Joy0Right", true);
	keyManager.addMapping(L"P1Down", L"Joy0Down", true);
	keyManager.addMapping(L"P1Kick", L"Joy0Button0", true);
	
	// - Player 2 movement (keys).
	keyManager.addMapping(L"P2Up", L"CursorUp", true);
	keyManager.addMapping(L"P2Left", L"CursorLeft", true);
	keyManager.addMapping(L"P2Right", L"CursorRight", true);
	keyManager.addMapping(L"P2Down", L"CursorDown", true);
	keyManager.addMapping(L"P2Kick", L"NumPad7", true);
	// - Player 2 movement (joystick).
	keyManager.addMapping(L"P2Up", L"Joy1Up", true);
	keyManager.addMapping(L"P2Left", L"Joy1Left", true);
	keyManager.addMapping(L"P2Right", L"Joy1Right", true);
	keyManager.addMapping(L"P2Down", L"Joy1Down", true);
	keyManager.addMapping(L"P2Kick", L"Joy1Button0", true);

	// - General.
	keyManager.addMapping(L"Escape", L"Escape", true);
#ifdef OSX
	keyManager.addMapping(L"Escape", L"Joy0Button9", true);
	keyManager.addMapping(L"Escape", L"Joy1Button9", true);
#else
	keyManager.addMapping(L"Escape", L"Joy0Button6", true);
	keyManager.addMapping(L"Escape", L"Joy1Button6", true);
#endif
	keyManager.addMapping(L"Restart", L"r", true);
#ifdef OSX
	keyManager.addMapping(L"Restart", L"Joy0Button8", true);
	keyManager.addMapping(L"Restart", L"Joy1Button8", true);
#else
	keyManager.addMapping(L"Restart", L"Joy0Button7", true);
	keyManager.addMapping(L"Restart", L"Joy1Button7", true);
#endif
	keyManager.addMapping(L"Action", L"Space", true);
	keyManager.addMapping(L"Action", L"Return", true);

	//Fill out helpText.

	//Set the LoadingScreen colours.
	setLoadingColours(0.0f,
					  ThreeFloats(1.0f, 0.5f, 0.5f),
					  ThreeFloats(0.52734375f, 0.5f, 1.0f),
					  0.125f);
}

//------------------------------------------------------------------------------
DrawerPtr AppSettings::getDrawer(const std::wstring& drawerType)
{
	if(drawerType == L"GLImmediateDrawer")
		return DrawerPtr(new GLImmediateDrawer());
	else
	{
		if(GLESDrawer::isSupported())
			return DrawerPtr(new GLESDrawer());
		else
		{
			DebugStatement(L"GLESDrawer not supported. Falling back to GLImmediateDrawer");
			return DrawerPtr(new GLImmediateDrawer());
		}
	}
}

//------------------------------------------------------------------------------
SounderPtr AppSettings::getSounder()
{
	return SounderPtr(new SnakeballSounder());
}

//------------------------------------------------------------------------------
GlobalDataPtr AppSettings::getGlobalData()
{
	return GlobalDataPtr(new ScreamingSnakeballGlobalData());
}

