//	OptionsFile.cpp - Simple class used to save/restore options.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "OptionsFile.h"
#include "AppSettings.h"
#include "UTF8File.h"

#include <sstream>

//------------------------------------------------------------------------------
OptionsFile::OptionsFile()
{
	FilePath path(FilePath::getAppDataPath().getChild(AppSettings::applicationName).getChild(L"options.txt"));
	UTF8File phil(path);

	if(path.exists())
	{
		std::wstring tempstr;

		while(!phil.readLine(tempstr))
		{
			options.insert(std::make_pair(tempstr.substr(0, tempstr.find_first_of(L':')),
										  tempstr.substr(tempstr.find_first_of(L':')+1)));
		}
	}
}

//------------------------------------------------------------------------------
OptionsFile::~OptionsFile()
{
	FilePath path(FilePath::getAppDataPath().getChild(AppSettings::applicationName).getChild(L"options.txt"));
	UTF8File phil(path);
	std::map<std::wstring, std::wstring>::iterator it;

	for(it=options.begin();it!=options.end();++it)
	{
		std::wstringstream tempstr;

		tempstr << it->first << L":" << it->second << std::endl;
		phil.writeText(tempstr.str());
	}
}

//------------------------------------------------------------------------------
void OptionsFile::setOption(const std::wstring& option, float value)
{
	std::map<std::wstring, std::wstring>::iterator it;
	std::wstringstream tempstr;

	tempstr << value;

	it = options.find(option);
	if(it != options.end())
		it->second = tempstr.str();
	else
		options.insert(std::make_pair(option, tempstr.str()));
}

//------------------------------------------------------------------------------
void OptionsFile::setOption(const std::wstring& option, int value)
{
	std::map<std::wstring, std::wstring>::iterator it;
	std::wstringstream tempstr;

	tempstr << value;

	it = options.find(option);
	if(it != options.end())
		it->second = tempstr.str();
	else
		options.insert(std::make_pair(option, tempstr.str()));
}

//------------------------------------------------------------------------------
void OptionsFile::setOption(const std::wstring& option,
							const::std::wstring& value)
{
	std::map<std::wstring, std::wstring>::iterator it;

	it = options.find(option);
	if(it != options.end())
		it->second = value;
	else
		options.insert(std::make_pair(option, value));
}

//------------------------------------------------------------------------------
float OptionsFile::getOptionFloat(const std::wstring& option) const
{
	float retval = -1.0f;
	std::wstringstream tempstr;
	std::map<std::wstring, std::wstring>::const_iterator it;

	it = options.find(option);
	if(it != options.end())
	{
		tempstr << it->second;
		tempstr >> retval;
	}

	return retval;
}

//------------------------------------------------------------------------------
int OptionsFile::getOptionInt(const std::wstring& option) const
{
	int retval = -1;
	std::wstringstream tempstr;
	std::map<std::wstring, std::wstring>::const_iterator it;

	it = options.find(option);
	if(it != options.end())
	{
		tempstr << it->second;
		tempstr >> retval;
	}

	return retval;
}

//------------------------------------------------------------------------------
const std::wstring OptionsFile::getOptionString(const std::wstring& option) const
{
	std::wstring retval;
	std::map<std::wstring, std::wstring>::const_iterator it;

	it = options.find(option);
	if(it != options.end())
		retval = it->second;

	return retval;
}
