//	VUMeter.cpp - Displays a simple VU Meter.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "VUMeter.h"

//------------------------------------------------------------------------------
VUMeter::VUMeter(const TwoFloats& pos, float mirror):
position(pos),
xScale(mirror, 1.0f),
value(0.0f)
{
	if(xScale.x < 0.0f)
		position.x += 259.0f;
}

//------------------------------------------------------------------------------
VUMeter::~VUMeter()
{

}

//------------------------------------------------------------------------------
void VUMeter::draw(shared_ptr<Drawer>& d)
{
	TwoFloats offset(value*259.0f, 0.0f);

	d->drawImage(L"PowerBarShadow", position+4.0f, xScale);

	if(xScale.x < 0.0f)
		offset.x *= xScale.x;

	if(value > 0.0f)
	{
		d->drawSubImage(L"PowerBarFront",
						position,
						0.0f,
						TwoFloats(value, 1.0f),
						xScale);
	}
	if(value < 1.0f)
	{
		d->drawSubImage(L"PowerBarBack",
						position+offset,
						TwoFloats(value, 0.0f),
						TwoFloats(1.0f-value, 1.0f),
						xScale,
						0.75f);
	}
}

//------------------------------------------------------------------------------
void VUMeter::setValue(float val)
{
	value = val;
}
