//	Wall.h - The wall class.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef WALL_H_
#define WALL_H_

#include "Collidable.h"
#include "c0xHeaders.h"

///	The wall class.
class Wall : public Collidable
{
  public:
	///	Constructor.
	Wall(const TwoFloats& pos, const std::wstring& realName);
	///	Destructor.
	~Wall();

	///	Sets the Wall's position.
	void setPosition(const TwoFloats& pos);
	///	Sets the Wall's radius.
	void setRadius(float val);

	///	Returns true if this entity wants to know when it collides with the named entity type.
	bool interestedInCollisionsWith(const std::wstring& entity) const;
	///	Called when this entity collides with another.
	bool collide(const shared_ptr<Collidable>& other,
				 GamePlayState& state);

	///	Returns the entity's position.
	const TwoFloats& getPosition() const {return (const TwoFloats&)position;};
	///	Returns the entity's speed.
	float getSpeed() const {return 0.0f;};
	///	Returns the entity's radius.
	float getRadius() const {return radius;};
	///	Returns true if other entities can pass through this one.
	bool getIncorporeal() const {return false;};
  private:
	///	The Wall's position.
	TwoFloats position;
	///	The Wall's radius.
	float radius;
};

#endif
